@@ -1,7 +1,7 @@
 /*********************************************************************
  *   Copyright 1993, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
- *   $Header: /upc/share/CVS/netcdf-3/nctest/slabs.c,v 1.12 2006/10/31 16:22:00 ed Exp $
+ *   $Header: /upc/share/CVS/netcdf-3/nctest/slabs.c,v 1.13 2009/02/11 16:17:39 ed Exp $
  *********************************************************************/
 
 #include <config.h>
@@ -38,31 +38,23 @@ val_stuff(type, v, ii, val)	/* v[ii] = val */
      long val;			/* value to store */
 {
     static char pname[] = "val_stuff";
-    union gp {
-	char cp[1];
-	short sp[1];
-	nclong lp[1];
-	float fp[1];
-	double dp[1];
-    } *gp;
 
-    gp = (union gp *) v;
     switch (type) {
       case NC_BYTE:
       case NC_CHAR:
-	gp->cp[ii] = (char) val;
+	 ((char *)v)[ii] = (char) val;
 	break;
       case NC_SHORT:
-	gp->sp[ii] = (short) val;
+	 ((short *)v)[ii] = (short) val;
 	break;
       case NC_LONG:
-	gp->lp[ii] = (nclong) val;
+	 ((nclong *)v)[ii] = (nclong) val;
 	break;
       case NC_FLOAT:
-	gp->fp[ii] = (float) val;
+	 ((float *)v)[ii] = (float) val;
 	break;
       case NC_DOUBLE:
-	gp->dp[ii] = (double) val;
+	 ((double *)v)[ii] = (double) val;
 	break;
       default:
 	error("%s: bad type, test program error", pname);
@@ -86,27 +78,19 @@ val_diff(type, v, ii, val)	/* v[ii] != val */
      long val;			/* value to compare with */
 {
     static char pname[] = "val_diff";
-    union gp {
-	char cp[1];
-	short sp[1];
-	nclong lp[1];
-	float fp[1];
-	double dp[1];
-    } *gp;
 
-    gp = (union gp *) v;
     switch (type) {
       case NC_BYTE:
       case NC_CHAR:
-	return (gp->cp[ii] != (char) val);
+	 return (((char *)v)[ii] != (char) val);
       case NC_SHORT:
-	return (gp->sp[ii] != (short) val);
+	 return (((short *)v)[ii] != (short) val);
       case NC_LONG:
-	return (gp->lp[ii] != (nclong) val);
+	 return (((nclong *)v)[ii] != (nclong) val);
       case NC_FLOAT:
-	return (gp->fp[ii] != (float) val);
+	 return (((float *)v)[ii] != (float) val);
       case NC_DOUBLE:
-	return (gp->dp[ii] != (double) val);
+	 return (((double *)v)[ii] != (double) val);
       default:
 	error("%s: bad type, test program error", pname);
 	return (-1);
